@@ -1,15 +1,14 @@
-use std::sync::Arc;
-
 use crate::{
     member::UnitMessage,
     network::NetworkDataInner,
-    testing::mock::{
-        configure_network, init_log, spawn_honest_member, NetworkData, NetworkHook, Spawner,
-    },
-    NodeCount, NodeIndex, Round, SpawnHandle,
+    testing::{init_log, spawn_honest_member, NetworkData},
+    Index, NodeCount, NodeIndex, Round, Signed, SpawnHandle,
 };
+use aleph_bft_mock::{BadSigning, Keychain, NetworkHook, Router, Spawner};
+use async_trait::async_trait;
 use futures::StreamExt;
 use parking_lot::Mutex;
+use std::sync::Arc;
 
 struct CorruptPacket {
     recipient: NodeIndex,
@@ -18,15 +17,23 @@ struct CorruptPacket {
     round: Round,
 }
 
-impl NetworkHook for CorruptPacket {
-    fn update_state(&mut self, data: &mut NetworkData, sender: NodeIndex, recipient: NodeIndex) {
+#[async_trait]
+impl NetworkHook<NetworkData> for CorruptPacket {
+    async fn update_state(
+        &mut self,
+        data: &mut NetworkData,
+        sender: NodeIndex,
+        recipient: NodeIndex,
+    ) {
         if self.recipient != recipient || self.sender != sender {
             return;
         }
         if let crate::NetworkData(NetworkDataInner::Units(UnitMessage::NewUnit(us))) = data {
-            let full_unit = &mut us.as_signable_mut();
+            let full_unit = us.clone().into_signable();
+            let index = full_unit.index();
             if full_unit.round() == self.round && full_unit.creator() == self.creator {
-                full_unit.set_round(0);
+                let bad_keychain: BadSigning<Keychain> = Keychain::new(0.into(), index).into();
+                *us = Signed::sign(full_unit, &bad_keychain).await.into();
             }
         }
     }
@@ -39,8 +46,9 @@ struct NoteRequest {
     requested: Arc<Mutex<bool>>,
 }
 
-impl NetworkHook for NoteRequest {
-    fn update_state(&mut self, data: &mut NetworkData, sender: NodeIndex, _: NodeIndex) {
+#[async_trait]
+impl NetworkHook<NetworkData> for NoteRequest {
+    async fn update_state(&mut self, data: &mut NetworkData, sender: NodeIndex, _: NodeIndex) {
         use NetworkDataInner::Units;
         use UnitMessage::RequestCoord;
         if sender == self.sender {
@@ -62,7 +70,7 @@ async fn request_missing_coord() {
     let censoring_node = NodeIndex(1);
     let censoring_round = 5;
 
-    let (mut net_hub, networks) = configure_network(n_members, 1.0);
+    let (mut net_hub, networks) = Router::new(n_members, 1.0);
     net_hub.add_hook(CorruptPacket {
         recipient: censored_node,
         sender: censoring_node,
@@ -84,8 +92,13 @@ async fn request_missing_coord() {
     let mut batch_rxs = Vec::new();
     for network in networks {
         let ix = network.index();
-        let (batch_rx, exit_tx, handle) =
-            spawn_honest_member(spawner.clone(), ix, n_members, network);
+        let (batch_rx, exit_tx, handle) = spawn_honest_member(
+            spawner.clone(),
+            ix,
+            n_members,
+            Arc::new(Mutex::new(vec![])),
+            network,
+        );
         batch_rxs.push(batch_rx);
         exits.push(exit_tx);
         handles.push(handle);
